@@ -1,10 +1,10 @@
-// $Id: body.cpp,v 1.35 2001/05/07 06:33:59 cabbey Exp $
+// $Id: body.cpp,v 1.44 2001/09/14 05:31:32 ericb Exp $
 //
 // This software is subject to the terms of the IBM Jikes Compiler
 // License Agreement available at the following URL:
-// http://www.ibm.com/research/jikes.
-// Copyright (C) 1996, 1998, International Business Machines Corporation
-// and others.  All Rights Reserved.
+// http://ibm.com/developerworks/opensource/jikes.
+// Copyright (C) 1996, 1998, 1999, 2000, 2001 International Business
+// Machines Corporation and others.  All Rights Reserved.
 // You must accept the terms of that agreement to use this software.
 //
 
@@ -12,8 +12,8 @@
 #include "semantic.h"
 #include "control.h"
 
-#ifdef	HAVE_JIKES_NAMESPACE
-namespace Jikes {	// Open namespace Jikes block
+#ifdef HAVE_JIKES_NAMESPACE
+namespace Jikes { // Open namespace Jikes block
 #endif
 
 void Semantic::ProcessBlockStatements(AstBlock *block_body)
@@ -176,7 +176,7 @@ void Semantic::ProcessLocalVariableDeclarationStatement(Ast *stmt)
     AccessFlags access_flags = ProcessLocalModifiers(local_decl);
 
     AstPrimitiveType *primitive_type = actual_type -> PrimitiveTypeCast();
-    TypeSymbol *field_type = (primitive_type ? field_type = FindPrimitiveType(primitive_type) : MustFindType(actual_type));
+    TypeSymbol *field_type = (primitive_type ? FindPrimitiveType(primitive_type) : MustFindType(actual_type));
 
     for (int i = 0; i < local_decl -> NumVariableDeclarators(); i++)
     {
@@ -184,22 +184,11 @@ void Semantic::ProcessLocalVariableDeclarationStatement(Ast *stmt)
         AstVariableDeclaratorId *name = variable_declarator -> variable_declarator_name;
         NameSymbol *name_symbol = lex_stream -> NameSymbol(name -> identifier_token);
 
-//
-// TODO: Confirm that this new test is indeed the case. In 1.0, only the more restricted test below was necessary.
-//
-//        if (LocalSymbolTable().FindVariableSymbol(name_symbol))
-//        {
-//            ReportSemError(SemanticError::DUPLICATE_LOCAL_VARIABLE_DECLARATION,
-//                           name -> identifier_token,
-//                           name -> identifier_token,
-//                           name_symbol -> Name());
-//        }
-//
-        SemanticEnvironment *where_found;
-        Tuple<VariableSymbol *> variables_found(2);
-        SearchForVariableInEnvironment(variables_found, where_found, state_stack.Top(), name_symbol, name -> identifier_token);
-        VariableSymbol *symbol = (variables_found.Length() > 0 ? variables_found[0] : (VariableSymbol *) NULL);
-        if (symbol && symbol -> IsLocal())
+        //
+        // According to JLS2 14.4.2, only check for a duplicate in
+        // the local class scope; don't worry about enclosing classes
+        //
+        if (LocalSymbolTable().FindVariableSymbol(name_symbol))
         {
             ReportSemError(SemanticError::DUPLICATE_LOCAL_VARIABLE_DECLARATION,
                            name -> identifier_token,
@@ -208,7 +197,7 @@ void Semantic::ProcessLocalVariableDeclarationStatement(Ast *stmt)
         }
         else
         {
-            symbol = LocalSymbolTable().Top() -> InsertVariableSymbol(name_symbol);
+            VariableSymbol *symbol = LocalSymbolTable().Top() -> InsertVariableSymbol(name_symbol);
             variable_declarator -> symbol = symbol;
 
             int num_dimensions = (array_type ? array_type -> NumBrackets() : 0) + name -> NumBrackets();
@@ -258,11 +247,17 @@ void Semantic::ProcessSynchronizedStatement(Ast *stmt)
 {
     AstSynchronizedStatement *synchronized_statement = (AstSynchronizedStatement *) stmt;
 
-    ProcessExpression(synchronized_statement -> expression);
+    //
+    // Notice that in the case of a complex string constant, it is
+    // vital to inline correctly; otherwise, we would not be using
+    // the correct object as the monitor.
+    //
+    ProcessExpressionOrStringConstant(synchronized_statement -> expression);
 
     synchronized_statement -> block -> is_reachable = synchronized_statement -> is_reachable;
 
-    if (synchronized_statement -> expression -> Type() -> Primitive())
+    if (synchronized_statement -> expression -> Type() -> Primitive() ||
+        synchronized_statement -> expression -> symbol == control.null_type)
     {
         ReportSemError(SemanticError::TYPE_NOT_REFERENCE,
                        synchronized_statement -> expression -> LeftToken(),
@@ -274,9 +269,13 @@ void Semantic::ProcessSynchronizedStatement(Ast *stmt)
              *block_body = synchronized_statement -> block;
 
     //
-    // "synchronized" blocks require two more local variable slots for synchronization,
-    // plus one extra variable slot if the containing method returns a value, plus an
-    // additional slot if the value returned is double or long.
+    // Synchronized blocks require one special local variable slot for the monitor.
+    // However, since a try-finally may require up to four slots, we reserve them
+    // all at this time.  Otherwise, the sequence {synchronized; variable declaration;
+    // try-finally} within the same enclosing block will cause a VerifyError.
+    // The VM should not care if some of these special slots are unused.
+    //
+    // TODO: Is it worth optimizing this and try-finally to avoid wasting variable slots?
     //
     BlockSymbol *enclosing_block_symbol = enclosing_block -> block_symbol;
     if (enclosing_block_symbol -> try_or_synchronized_variable_index == 0) // first such statement encountered in enclosing block?
@@ -285,9 +284,9 @@ void Semantic::ProcessSynchronizedStatement(Ast *stmt)
         enclosing_block_symbol -> max_variable_index += 2;
         if (ThisMethod() -> Type() != control.void_type)
         {
-             if (control.IsDoubleWordType(ThisMethod() -> Type()))
-                  enclosing_block_symbol -> max_variable_index += 2;
-             else enclosing_block_symbol -> max_variable_index += 1;
+            if (control.IsDoubleWordType(ThisMethod() -> Type()))
+                enclosing_block_symbol -> max_variable_index += 2;
+            else enclosing_block_symbol -> max_variable_index += 1;
         }
     }
 
@@ -310,12 +309,7 @@ void Semantic::ProcessSynchronizedStatement(Ast *stmt)
     if (LocalBlockStack().TopMaxEnclosedVariableIndex() < block -> max_variable_index)
         LocalBlockStack().TopMaxEnclosedVariableIndex() = block -> max_variable_index;
 
-    //
-    // If the synchronized_statement is enclosed in a loop and it contains a reachable continue statement
-    // then it may have already been marked as "can complete normally";
-    //
-    synchronized_statement -> can_complete_normally = synchronized_statement -> can_complete_normally ||
-                                                      synchronized_statement -> block -> can_complete_normally;
+    synchronized_statement -> can_complete_normally = synchronized_statement -> block -> can_complete_normally;
 
     block -> CompressSpace(); // space optimization
 
@@ -350,12 +344,7 @@ void Semantic::ProcessIfStatement(Ast *stmt)
         if_statement -> false_statement_opt -> is_reachable = if_statement -> is_reachable;
         ProcessBlock(if_statement -> false_statement_opt);
 
-        //
-        // If the if_statement is enclosed in a loop and it contains a reachable continue statement
-        // then it may have already been marked as "can complete normally";
-        //
-        if_statement -> can_complete_normally = if_statement -> can_complete_normally ||
-                                                if_statement -> true_statement -> can_complete_normally ||
+        if_statement -> can_complete_normally = if_statement -> true_statement -> can_complete_normally ||
                                                 if_statement -> false_statement_opt -> can_complete_normally;
     }
     else if_statement -> can_complete_normally = if_statement -> is_reachable;
@@ -951,7 +940,7 @@ void Semantic::ProcessReturnStatement(Ast *stmt)
     }
     else if (return_statement -> expression_opt)
     {
-        ProcessExpression(return_statement -> expression_opt);
+        ProcessExpressionOrStringConstant(return_statement -> expression_opt);
 
         if (this_method -> Type() == control.void_type)
         {
@@ -1118,20 +1107,26 @@ void Semantic::ProcessTryStatement(Ast *stmt)
 
     //
     // A try_statement containing a finally clause requires some extra local
-    // variables in its immediately enclosing block. If it is enclosed in a method
-    // that returns void then 2 extra elements are needed. If the method
-    // returns a long or a double value, two additional elements are needed.
-    // Otherwise, one additional element is needed.
-    // If this try_statement is the first try_statement with a finally clause
-    // that was encountered in the immediately enclosing block, we allocate
-    // two extra slots for the special local variables.
+    // variables in its immediately enclosing block. The first holds an
+    // uncaught exception from the try or catch block.  The second holds the
+    // return address of the jsr.  And if the method has a return type, 1-2
+    // more slots are needed to hold the return value in the case of an
+    // abrupt exit from a try or catch block.
+    //
+    // Meanwhile, statements within try or catch blocks cannot share local
+    // variables with the finally block, because of a potential VerifyError if
+    // the finally overwrites a register holding a monitor of an enclosed
+    // synchronized statement during an abrupt exit.
     //
     AstBlock *enclosing_block = LocalBlockStack().TopBlock();
+    int max_variable_index = enclosing_block -> block_symbol -> max_variable_index;
+
     if (try_statement -> finally_clause_opt)
     {
         BlockSymbol *enclosing_block_symbol = enclosing_block -> block_symbol;
-        if (enclosing_block_symbol -> try_or_synchronized_variable_index == 0) // first such statement encountered in enclosing block?
+        if (enclosing_block_symbol -> try_or_synchronized_variable_index == 0)
         {
+            // first such statement encountered in enclosing block?
             enclosing_block_symbol -> try_or_synchronized_variable_index = enclosing_block_symbol -> max_variable_index;
             enclosing_block_symbol -> max_variable_index += 2;
             if (ThisMethod() -> Type() != control.void_type)
@@ -1143,17 +1138,21 @@ void Semantic::ProcessTryStatement(Ast *stmt)
         }
 
         //
-        // A finally block is processed in the environment of its immediate enclosing block.
-        // (as opposed to the environment of its associated try block).
+        // A finally block is processed in the environment of its immediate
+        // enclosing block (as opposed to the environment of its associated
+        // try block).
         //
         // Note that the finally block must be processed prior to the other
-        // blocks in the try statement, because the computation of whether or not
-        // an exception is catchable in a try statement depends on the termination
-        // status of the associated finally block. See CatchableException function.
+        // blocks in the try statement, because the computation of whether or
+        // not an exception is catchable in a try statement depends on the
+        // termination status of the associated finally block. See
+        // CatchableException function. In addition, any variables used in
+        // the finally block cannot be safely used in the other blocks.
         //
         AstBlock *block_body = try_statement -> finally_clause_opt -> block;
         block_body -> is_reachable = try_statement -> is_reachable;
         ProcessBlock(block_body);
+        max_variable_index = block_body -> block_symbol -> max_variable_index;
     }
 
     //
@@ -1211,10 +1210,11 @@ void Semantic::ProcessTryStatement(Ast *stmt)
 
         AstBlock *block_body = clause -> block;
         //
-        // Guess that the number of elements in the table will not exceed the number of statements + the clause parameter.
+        // Guess that the number of elements in the table will not exceed the
+        // number of statements + the clause parameter.
         //
         BlockSymbol *block = LocalSymbolTable().Top() -> InsertBlockSymbol(block_body -> NumStatements() + 1);
-        block -> max_variable_index = enclosing_block -> block_symbol -> max_variable_index;
+        block -> max_variable_index = max_variable_index;
         LocalSymbolTable().Push(block -> Table());
 
         AccessFlags access_flags = ProcessFormalModifiers(parameter);
@@ -1245,7 +1245,8 @@ void Semantic::ProcessTryStatement(Ast *stmt)
         LocalSymbolTable().Pop();
 
         //
-        // Update the information for the block that immediately encloses the current block.
+        // Update the information for the block that immediately encloses
+        // the current block.
         //
         if (LocalBlockStack().TopMaxEnclosedVariableIndex() < block -> max_variable_index)
             LocalBlockStack().TopMaxEnclosedVariableIndex() = block -> max_variable_index;
@@ -1270,7 +1271,34 @@ void Semantic::ProcessTryStatement(Ast *stmt)
     TryExceptionTableStack().Push(exception_set);
 
     try_statement -> block -> is_reachable = try_statement -> is_reachable;
-    ProcessBlock(try_statement -> block);
+    AstBlock *block_body = try_statement -> block;
+    //
+    // Guess that the number of elements in the table will not exceed the
+    // number of statements + 3. This padding allows extra variable
+    // declarations in things like for-init, without expensive reallocation.
+    //
+    BlockSymbol *block = LocalSymbolTable().Top() -> InsertBlockSymbol(block_body -> NumStatements() + 3);
+    block -> max_variable_index = max_variable_index;
+    LocalSymbolTable().Push(block -> Table());
+
+    block_body -> block_symbol = block;
+    block_body -> nesting_level = LocalBlockStack().Size();
+    LocalBlockStack().Push(block_body);
+
+    ProcessBlockStatements(block_body);
+    
+    LocalBlockStack().Pop();
+    LocalSymbolTable().Pop();
+
+    //
+    // Update the information for the block that immediately encloses the
+    // current block.
+    //
+    if (LocalBlockStack().TopMaxEnclosedVariableIndex() < block -> max_variable_index)
+        LocalBlockStack().TopMaxEnclosedVariableIndex() = block -> max_variable_index;
+
+    block -> CompressSpace(); // space optimization
+
     if (try_statement -> block -> can_complete_normally)
         try_statement -> can_complete_normally = true;
 
@@ -1470,6 +1498,10 @@ void Semantic::ProcessClassDeclaration(Ast *stmt)
     inner_type -> SetLocation();
     inner_type -> SetSignature(control);
 
+    //
+    // Local classes are never static; however, for error checking, it is
+    // easier to temporarily mark it as such.  We reset it below...
+    //
     if (StaticRegion())
          inner_type -> SetACC_STATIC();
     else inner_type -> InsertThis(0);
@@ -1486,62 +1518,21 @@ void Semantic::ProcessClassDeclaration(Ast *stmt)
 
     UpdateLocalConstructors(inner_type);
 
+    //
+    // Local classes are not static. See above.
+    //
+    inner_type -> ResetACC_STATIC();
+
     return;
 }
 
 
 void Semantic::ProcessThisCall(AstThisCall *this_call)
 {
-    TypeSymbol *this_type = ThisType(),
-               *containing_type = this_type -> ContainingType();
+    TypeSymbol *this_type = ThisType();
 
     ExplicitConstructorInvocation() = this_call; // signal that we are about to process an explicit constructor invocation
 
-    if (this_call -> base_opt)
-    {
-        ProcessExpression(this_call -> base_opt);
-
-        TypeSymbol *expr_type = this_call -> base_opt -> Type();
-        if (expr_type != control.no_type)
-        {
-            if (! containing_type)
-            {
-                ReportSemError(SemanticError::TYPE_NOT_INNER_CLASS,
-                               this_call -> base_opt -> LeftToken(),
-                               this_call -> base_opt -> RightToken(),
-                               this_type -> ContainingPackage() -> PackageName(),
-                               this_type -> ExternalName(),
-                               expr_type -> ContainingPackage() -> PackageName(),
-                               expr_type -> ExternalName());
-                this_call -> base_opt -> symbol = control.no_type;
-            }
-            //
-            // 1.2 change. In 1.1, we used to allow access to any subclass of type. Now, there must
-            // be a perfect match.
-            //
-            // else if (! expr_type -> IsSubclass(containing_type))
-            //
-            else if (expr_type != containing_type)
-            {
-                ReportSemError(SemanticError::INVALID_ENCLOSING_INSTANCE,
-                               this_call -> base_opt -> LeftToken(),
-                               this_call -> base_opt -> RightToken(),
-                               this_type -> ContainingPackage() -> PackageName(),
-                               this_type -> ExternalName(),
-                               containing_type -> ContainingPackage() -> PackageName(),
-                               containing_type -> ExternalName(),
-                               expr_type -> ContainingPackage() -> PackageName(),
-                               expr_type -> ExternalName());
-                this_call -> base_opt -> symbol = control.no_type;
-            }
-        }
-    }
-    else // (! this_call -> base_opt)
-    {
-        if (this_type -> IsInner())
-            this_call -> base_opt = CreateAccessToType(this_call, containing_type);
-    }
-
     bool no_bad_argument = true;
 
     for (int i = 0; i < this_call -> NumArguments(); i++)
@@ -2086,6 +2077,9 @@ void Semantic::ProcessConstructorBody(AstConstructorDeclaration *constructor_dec
 
 void Semantic::ProcessExecutableBodies(SemanticEnvironment *environment, AstClassBody *class_body)
 {
+    if (compilation_unit -> kind == Ast::BAD_COMPILATION)
+        return; // errors were detected, exit now
+
     state_stack.Push(environment);
     TypeSymbol *this_type = ThisType();
 
@@ -2154,26 +2148,6 @@ void Semantic::ProcessExecutableBodies(SemanticEnvironment *environment, AstClas
             MethodSymbol *this_method = ThisMethod();
             if (this_method)
             {
-                for (int l = 0; l < this_method -> NumFormalParameters(); l++)
-                {
-                    VariableSymbol *parm = this_method -> FormalParameter(l);
-                    AstVariableDeclaratorId *name = parm -> declarator -> variable_declarator_name;
-
-                    SemanticEnvironment *where_found;
-                    Tuple<VariableSymbol *> variables_found(2);
-                    SearchForVariableInEnvironment(variables_found, where_found, state_stack.Top(),
-                                                   parm -> Identity(),
-                                                   name -> identifier_token);
-                    VariableSymbol *symbol = (variables_found.Length() > 0 ? variables_found[0] : (VariableSymbol *) NULL);
-                    if (symbol && symbol -> IsLocal())
-                    {
-                        ReportSemError(SemanticError::DUPLICATE_LOCAL_VARIABLE_DECLARATION,
-                                       name -> identifier_token,
-                                       name -> identifier_token,
-                                       parm -> Name());
-                    }
-                }
-
                 AstConstructorBlock *constructor_block = constructor_decl -> constructor_body;
                 if (constructor_block -> explicit_constructor_invocation_opt &&
                     constructor_block -> explicit_constructor_invocation_opt -> ThisCallCast())
@@ -2238,29 +2212,6 @@ void Semantic::ProcessExecutableBodies(SemanticEnvironment *environment, AstClas
         MethodSymbol *this_method = ThisMethod();
         if (this_method)
         {
-            //
-            // TODO: Confirm that this new test is indeed necessary. In 1.0, a more restricted test was used...
-            //
-            for (int i = 0; i < this_method -> NumFormalParameters(); i++)
-            {
-                VariableSymbol *parm = this_method -> FormalParameter(i);
-                AstVariableDeclaratorId *name = parm -> declarator -> variable_declarator_name;
-
-                SemanticEnvironment *where_found;
-                Tuple<VariableSymbol *> variables_found(2);
-                SearchForVariableInEnvironment(variables_found, where_found, state_stack.Top(),
-                                               parm -> Identity(),
-                                               name -> identifier_token);
-                VariableSymbol *symbol = (variables_found.Length() > 0 ? variables_found[0] : (VariableSymbol *) NULL);
-                if (symbol && symbol -> IsLocal())
-                {
-                    ReportSemError(SemanticError::DUPLICATE_LOCAL_VARIABLE_DECLARATION,
-                                   name -> identifier_token,
-                                   name -> identifier_token,
-                                   parm -> Name());
-                }
-            }
-
             LocalSymbolTable().Push(this_method -> block_symbol -> Table());
             LocalBlockStack().max_size = 0;
 
@@ -2353,7 +2304,7 @@ void Semantic::ProcessExecutableBodies(AstInterfaceDeclaration *interface_declar
     return;
 }
 
-#ifdef	HAVE_JIKES_NAMESPACE
-}			// Close namespace Jikes block
+#ifdef HAVE_JIKES_NAMESPACE
+} // Close namespace Jikes block
 #endif
 
