@@ -1,12 +1,13 @@
-// $Id: control.h,v 1.33 2001/04/28 19:34:37 cabbey Exp $
+// $Id: control.h,v 1.36 2001/09/14 05:31:32 ericb Exp $ -*- c++ -*-
 //
 // This software is subject to the terms of the IBM Jikes Compiler
 // License Agreement available at the following URL:
-// http://www.ibm.com/research/jikes.
-// Copyright (C) 1996, 1998, International Business Machines Corporation
-// and others.  All Rights Reserved.
+// http://ibm.com/developerworks/opensource/jikes.
+// Copyright (C) 1996, 1998, 1999, 2000, 2001 International Business
+// Machines Corporation and others.  All Rights Reserved.
 // You must accept the terms of that agreement to use this software.
 //
+
 #ifndef control_INCLUDED
 #define control_INCLUDED
 
@@ -16,14 +17,8 @@
 #include "tuple.h"
 #include "set.h"
 
-/*
-//FIXME: need to readdress this include stuff
-#include <iostream.h>
-#include <stdio.h>
-*/
-
-#ifdef	HAVE_JIKES_NAMESPACE
-namespace Jikes {	// Open namespace Jikes block
+#ifdef HAVE_JIKES_NAMESPACE
+namespace Jikes { // Open namespace Jikes block
 #endif
 
 class StoragePool;
@@ -255,11 +250,6 @@ public:
         return (Error_type ? Error_type : Error_type = GetType(system_package, StringConstant::US_Error));
     }
 
-    inline TypeSymbol *Vector()
-    {
-        return (Vector_type ? Vector_type : Vector_type = GetType(java_util_package, StringConstant::US_Vector));
-    }
-
     void InitNoClassDefFoundErrorInfo();
     inline TypeSymbol *NoClassDefFoundError()
     {
@@ -562,7 +552,6 @@ private:
                *RuntimeException_type,
                *ClassNotFoundException_type,
                *Error_type,
-               *Vector_type,
                *NoClassDefFoundError_type,
                *StringBuffer_type;
 
@@ -607,9 +596,9 @@ private:
     FileSymbol *FindOrInsertJavaInputFile(wchar_t *, int);
 };
 
-#ifdef	HAVE_JIKES_NAMESPACE
-}			// Close namespace Jikes block
+#ifdef HAVE_JIKES_NAMESPACE
+} // Close namespace Jikes block
 #endif
 
-#endif /* control_INCLUDED */
+#endif // control_INCLUDED
 
