@@ -1,10 +1,10 @@
-// $Id: option.cpp,v 1.55 2001/05/11 05:07:55 cabbey Exp $
+// $Id: option.cpp,v 1.61 2001/09/29 01:00:27 cabbey Exp $
 //
 // This software is subject to the terms of the IBM Jikes Compiler
 // License Agreement available at the following URL:
-// http://www.ibm.com/research/jikes.
-// Copyright (C) 1996, 1998, International Business Machines Corporation
-// and others.  All Rights Reserved.
+// http://ibm.com/developerworks/opensource/jikes.
+// Copyright (C) 1996, 1998, 1999, 2000, 2001 International Business
+// Machines Corporation and others.  All Rights Reserved.
 // You must accept the terms of that agreement to use this software.
 //
 
@@ -13,57 +13,107 @@
 #include "error.h"
 #include "case.h"
 
-//FIXME: include stuff
-//#include <ctype.h>
-
-
-// FIXME: this and other # defined things need to go in platform.cpp!
-#ifdef HAVE_SYS_CYGWIN_H
-#include <sys/cygwin.h>
-#endif
-
-#ifdef	HAVE_JIKES_NAMESPACE
-namespace Jikes {	// Open namespace Jikes block
+#ifdef HAVE_JIKES_NAMESPACE
+namespace Jikes { // Open namespace Jikes block
 #endif
 
 //
+// Look for arguments in a file and add them to the passed
+// in tuple. If the file does not exist or cannot be read
+// return false. Return true otherwise.
 //
-//
-bool ArgumentExpander::ArgumentExpanded(Tuple<char *> &arguments, char *file_name)
+bool ArgumentExpander::ExpandAtFileArgument(Tuple<char *> &arguments,
+    char *file_name)
 {
     struct stat status;
-    FILE *afile = fopen(file_name, "r");
+    FILE *afile = SystemFopen(file_name, "r");
+    bool foundFile = false;
+
     if (afile && (SystemStat(file_name, &status) == 0))
     {
-        char *buffer = new char[status.st_size + 2];
-        int file_size = fread(buffer, 1, status.st_size, afile);
+        char *buffer;
+        int file_size;
+        char *start = NULL;
+        char *end = NULL;
+        char *eol = NULL;
+
+        foundFile = true;
+        buffer = new char[status.st_size + 2];
+        file_size = SystemFread(buffer, 1, status.st_size, afile);
+        //assert(status.st_size == file_size); // Fails under Cygwin (fopen "b" flag)
         buffer[file_size] = '\n';
-        for (int k = 0; k < file_size; k++)
+        buffer[file_size+1] = '\0';
+
+        for (char *ptr = buffer; *ptr; )
         {
-            // FIXME : When \r is replaced by \n, we should not need to check for U_CARRIAGE_RETURN.
-            // Skip spaces and line termination characters
-            while (buffer[k] == U_SPACE || buffer[k] == U_LINE_FEED || buffer[k] == U_CARRIAGE_RETURN)
-                k++;
-            // If we are at the end of the file, there must not have been any arguments in the file
-            if (k >= file_size)
+            // Skip spaces, tabs, and EOL until we find some text
+
+            while (start == NULL && *ptr) {
+                switch (*ptr) {
+                case U_SPACE:
+                case U_HORIZONTAL_TAB:
+                case U_LINE_FEED:
+                case U_CARRIAGE_RETURN:
+                    break; // Out of the switch not the while
+                default:
+                    start = ptr;
+                    end = ptr;
+                }
+                ptr++;
+            }
+
+            // If at end of the buffer, no arguments are left
+            if (! *ptr)
                 break;
 
-            int n;
-            for (n = k + 1; ! (buffer[n] == U_SPACE || buffer[n] == U_LINE_FEED || buffer[n] == U_CARRIAGE_RETURN); n++)
-                ;
-            buffer[n] = U_NULL;
-            char *str = new char[n - k + 1];
-            strcpy(str, &buffer[k]);
-            arguments.Next() = str;
-            k = n;
+            // Find the end of this line, save last non space
+            // or tab position in the end ptr
+
+            while (eol == NULL)
+            {
+                switch (*ptr)
+                {
+                case U_LINE_FEED:
+                case U_CARRIAGE_RETURN:
+                    eol = ptr;
+                    break;
+                case U_SPACE:
+                case U_HORIZONTAL_TAB:
+                    break; // ignore tabs and spaces
+                default:
+                    end = ptr;
+                }
+                ptr++;
+
+            }
+
+            // Ignore double quotes so "Foo Bar.java" works.
+
+            if (start < end &&
+                *start == U_DOUBLE_QUOTE &&
+                *end == U_DOUBLE_QUOTE) {
+                start++;
+                end--;
+            }
+
+            // Copy arg into new string and add to tuple
+            *(end+1) = '\0';
+            char *arg = new char[strlen(start) + 1];
+            strcpy(arg, start);
+            arguments.Next() = arg;
+
+            // Reinit the pointers
+            start = NULL;
+            end = NULL;
+            eol = NULL;
         }
+
         delete [] buffer;
+    }
+    if (afile != NULL)
         fclose(afile);
 
-        return true;
-    }
-
-    return false;
+    return foundFile;
 }
 
 
@@ -73,7 +123,7 @@ ArgumentExpander::ArgumentExpander(int argc_, char *argv_[])
     for (int i = 0; i < argc_; i++)
     {
         char *argument = argv_[i];
-        if (argument[0] != '@' || (! ArgumentExpanded(arguments, argument + 1)))
+        if (argument[0] != '@' || (! ExpandAtFileArgument(arguments, argument + 1)))
         {
             char *str = new char[strlen(argument) + 1];
             strcpy(str, argument);
@@ -111,11 +161,17 @@ ArgumentExpander::ArgumentExpander(Tuple<char> &line)
                 argument[i] = line[k];
             argument[length] = U_NULL;
 
-            if (argument[0] == '@' && ArgumentExpanded(arguments, argument + 1))
-                 delete argument;
-            else arguments.Next() = argument;
+            if (argument[0] == '@' &&
+                ExpandAtFileArgument(arguments, argument + 1))
+            {
+                delete [] argument;
+            }
+            else
+            {
+                arguments.Next() = argument;
+            }
         }
-    } while(end < line.Length());
+    } while (end < line.Length());
 
     argc = arguments.Length();
     argv = new char*[argc];
@@ -160,9 +216,48 @@ void Option::SaveCurrentDirectoryOnDisk(char c)
 
     return;
 }
-#endif
+#endif // WIN32_FILE_SYSTEM
 
 
+// 
+// Skip leading whitespace and copy the rest to a new string
+// so we don't have to worry about affecting the environment
+// variable. If input value is NULL or consists of only whitespace
+// characters, returns NULL.
+//
+static inline char* makeStrippedCopy(char* value)
+{
+    if (value == NULL)
+        return NULL;
+
+    char* result = NULL;
+    while (isspace(*value))
+        value++;
+
+    if (*value)
+    {
+        result = new char[strlen(value) + 1];
+        strcpy(result, value);
+
+#ifdef HAVE_CYGWIN_WIN32_TO_POSIX_PATH_LIST
+        //
+        // Under Cygwin, we convert a Windows-style path into a UNIX-style
+        // path.  A path like "C:\Cygwin\tmp;C:\Windows" is converted into
+        // "/tmp:/cygdrive/c/Windows" (assuming C:\Cygwin is cygroot).  We
+        // can then parse it using the UNIX path seperator char ':'.
+        //
+        if (! cygwin_posix_path_list_p(result))
+        {
+            char* temp = new char[cygwin_win32_to_posix_path_list_buf_size(result)];
+            cygwin_win32_to_posix_path_list(result, temp);
+            delete[] result;
+            result = temp;
+        }
+#endif // CYGWIN_WIN32_TO_POSIX_PATH_LIST
+    }
+    return result;
+}
+
 Option::Option(ArgumentExpander &arguments) :
                                               first_file_index(arguments.argc),
                                               debug_trap_op(0),
@@ -207,91 +302,48 @@ Option::Option(ArgumentExpander &arguments) :
         current_directory[Case::ToAsciiUpper(main_disk)] = main_current_directory;
     }
     current_directory[0] = main_current_directory;
-#endif
+#endif // WIN32_FILE_SYSTEM
 
-    char * paths_buffer;
     Tuple<int> filename_index(2048);
 
     for (int i = 1; i < arguments.argc; i++)
     {
         if (arguments.argv[i][0] == '-')
         {
-            if (strcmp(arguments.argv[i],"-classpath") == 0 && ((i + 1) < arguments.argc))
+            if (strcmp(arguments.argv[i], "-classpath") == 0 &&
+                ((i + 1) < arguments.argc))
             {
-                classpath = arguments.argv[++i];
-		
-                // Create a copy of the -classpath argument so we can modify
+                // Create a clean copy of the -classpath argument so we can modify
                 //   this copy and delete it later in ~JikesOption
-                paths_buffer = new char[strlen(classpath)+1];
-                strcpy(paths_buffer, classpath);
-                classpath = paths_buffer;
-
-#ifdef EBCDIC
-                //
-                //  Maintain CLASSPATH in ASCII and translate back to EBCDIC when building file name
-                //
-                for (int k = 0; k < strlen(classpath); k++)
-                    classpath[k] = Code::ToASCII(classpath[k]);
-#endif
+                classpath = makeStrippedCopy(arguments.argv[++i]);
             }
-            else if (strcmp(arguments.argv[i],"-bootclasspath") == 0 && ((i + 1) < arguments.argc))
+            else if (strcmp(arguments.argv[i], "-bootclasspath") == 0 &&
+                     ((i + 1) < arguments.argc))
             {
-                bootclasspath = arguments.argv[++i];
-		
-                // Create a copy of the -bootclasspath argument so we can
+                // Create a clean copy of the -bootclasspath argument so we can
                 // modify this copy and delete it later in ~JikesOption
-                paths_buffer = new char[strlen(bootclasspath)+1];
-                strcpy(paths_buffer, bootclasspath);
-                bootclasspath = paths_buffer;
-
-#ifdef EBCDIC
-                //
-                //  Maintain CLASSPATH in ASCII and translate back to EBCDIC when building file name
-                //
-                for (int k = 0; k < strlen(bootclasspath); k++)
-                    bootclasspath[k] = Code::ToASCII(bootclasspath[k]);
-#endif
+                bootclasspath = makeStrippedCopy(arguments.argv[++i]);
             }
-            else if (strcmp(arguments.argv[i],"-extdirs") == 0 && ((i + 1) < arguments.argc))
+            else if (strcmp(arguments.argv[i], "-extdirs") == 0 &&
+                     ((i + 1) < arguments.argc))
             {
-                extdirs = arguments.argv[++i];
-		
-                // Create a copy of the -extdirs argument so we can modify
+                // Create a clean copy of the -extdirs argument so we can modify
                 // this copy and delete it later in ~JikesOption
-                paths_buffer = new char[strlen(extdirs)+1];
-                strcpy(paths_buffer, extdirs);
-                extdirs = paths_buffer;
-
-#ifdef EBCDIC
-                //
-                //  Maintain CLASSPATH in ASCII and translate back to EBCDIC when building file name
-                //
-                for (int k = 0; k < strlen(extdirs); k++)
-                    extdirs[k] = Code::ToASCII(extdirs[k]);
-#endif
+                extdirs = makeStrippedCopy(arguments.argv[++i]);
             }
-            else if (strcmp(arguments.argv[i],"-sourcepath") == 0 && ((i + 1) < arguments.argc))
+            else if (strcmp(arguments.argv[i], "-sourcepath") == 0 &&
+                     ((i + 1) < arguments.argc))
             {
-                sourcepath = arguments.argv[++i];
-		
-                // Create a copy of the -sourcepath argument so we can
+                // Create a clean copy of the -sourcepath argument so we can
                 // modify this copy and delete it later in ~JikesOption
-                paths_buffer = new char[strlen(sourcepath)+1];
-                strcpy(paths_buffer, sourcepath);
-                sourcepath = paths_buffer;
-
-#ifdef EBCDIC
-                //
-                //  Maintain CLASSPATH in ASCII and translate back to EBCDIC when building file name
-                //
-                for (int k = 0; k < strlen(sourcepath); k++)
-                    sourcepath[k] = Code::ToASCII(sourcepath[k]);
-#endif
+                sourcepath = makeStrippedCopy(arguments.argv[++i]);
             }
-            else if (strcmp(arguments.argv[i], "-depend") == 0 || strcmp(arguments.argv[i], "-Xdepend") == 0)
+            else if (strcmp(arguments.argv[i], "-depend") == 0 ||
+                     strcmp(arguments.argv[i], "-Xdepend") == 0)
                  depend = true;
 #if defined(HAVE_LIBICU_UC) || defined(HAVE_ICONV_H)
-            else if (strcmp(arguments.argv[i], "-encoding") == 0 && ((i + 1) < arguments.argc))
+            else if (strcmp(arguments.argv[i], "-encoding") == 0 &&
+                     ((i + 1) < arguments.argc))
             {
                 i++;
                 encoding = new char[strlen(arguments.argv[i]) + 1];
@@ -306,21 +358,22 @@ Option::Option(ArgumentExpander &arguments) :
                 continue;
             }
 #endif // defined(HAVE_LIBICU_UC) || defined(HAVE_ICONV_H)
-            else if (strcmp(arguments.argv[i],"-verbose") == 0)
+            else if (strcmp(arguments.argv[i], "-verbose") == 0)
                  verbose = true;
-            else if (strcmp(arguments.argv[i],"-g") == 0)
+            else if (strcmp(arguments.argv[i], "-g") == 0)
                  g = true;
             else if (strcmp(arguments.argv[i], "-O") == 0)
                  O = true;
-            else if (strcmp(arguments.argv[i],"-deprecation") == 0)
+            else if (strcmp(arguments.argv[i], "-deprecation") == 0)
                  deprecation = true;
-            else if (strcmp(arguments.argv[i],"-nowrite") == 0)
+            else if (strcmp(arguments.argv[i], "-nowrite") == 0)
                  nowrite = true;
-            else if (strcmp(arguments.argv[i],"-nowarn") == 0)
+            else if (strcmp(arguments.argv[i], "-nowarn") == 0)
                  nowarn = true;
-            else if (strcmp(arguments.argv[i],"-Xstdout") == 0)
+            else if (strcmp(arguments.argv[i], "-Xstdout") == 0)
                  Coutput.StandardOutput();
-            else if (strcmp(arguments.argv[i], "-d") == 0 && ((i + 1) < arguments.argc))
+            else if (strcmp(arguments.argv[i], "-d") == 0 &&
+                     ((i + 1) < arguments.argc))
             {
                 ++i;
 #if defined(UNIX_FILE_SYSTEM)
@@ -352,14 +405,7 @@ Option::Option(ArgumentExpander &arguments) :
 
                 if (! directory)
                     bad_options.Next() = new OptionError(SemanticError::INVALID_DIRECTORY, arguments.argv[i]);
-#endif
-#ifdef EBCDIC
-                //
-                // need to translate directory name to ASCII
-                //
-                for (int k = 0; k < directory_length; k++)
-                    directory[k] = Code::ToASCII(directory[k]);
-#endif
+#endif // WIN32_FILE_SYSTEM
                 if (directory)
                 {
                     for (char *ptr = directory; *ptr; ptr++)
@@ -379,10 +425,6 @@ Option::Option(ArgumentExpander &arguments) :
                 debug_unparse_ast = true;
                 debug_unparse_ast_debug = true;
             }
-#ifdef EBCDIC
-            else if (strcmp(arguments.argv[i], "+ASCII") == 0)
-                     ascii = true;
-#endif
             else if (strcmp(arguments.argv[i], "+B") == 0)
                  bytecode = false;
             else if (strcmp(arguments.argv[i], "+c") == 0)
@@ -391,16 +433,16 @@ Option::Option(ArgumentExpander &arguments) :
                  debug_dump_class = true;
             else if (strcmp(arguments.argv[i], "+OLDCSO") == 0)
                  old_classpath_search_order = true;
-            else if (strcmp(arguments.argv[i],"+D") == 0)
+            else if (strcmp(arguments.argv[i], "+D") == 0)
             {
                  dump_errors = true;
                  errors = false;
             }
-            else if (strcmp(arguments.argv[i],"+E") == 0)
+            else if (strcmp(arguments.argv[i], "+E") == 0)
             {
                 errors = false;
             }
-            else if (arguments.argv[i][0] == '+' && arguments.argv[i][1] == 'K')
+            else if (arguments.argv[i][1] == 'K')
             {
                 char *name = arguments.argv[i] + 2,
                      *image;
@@ -443,9 +485,9 @@ Option::Option(ArgumentExpander &arguments) :
                     }
                 }
             }
-            else if (strcmp(arguments.argv[i],"+F") == 0)
+            else if (strcmp(arguments.argv[i], "+F") == 0)
                  full_check = true;
-            else if (strcmp(arguments.argv[i],"+M") == 0)
+            else if (strcmp(arguments.argv[i], "+M") == 0)
             {
                  makefile = true;
                  full_check = true;
@@ -455,18 +497,18 @@ Option::Option(ArgumentExpander &arguments) :
                  makefile = true;
                  dependence_report=true;
                  full_check = true;
-		 dependence_report_name =
-		     new char[strlen(&arguments.argv[i][4]) + 1];
-		 strcpy(dependence_report_name, &arguments.argv[i][4]);
+                 dependence_report_name =
+                     new char[strlen(&arguments.argv[i][4]) + 1];
+                 strcpy(dependence_report_name, &arguments.argv[i][4]);
             }
             else if (strcmp(arguments.argv[i], "+O") == 0)
             {
                  debug_trap_op = atoi(arguments.argv[i + 1]);
                  i++;
             }
-            else if (strcmp(arguments.argv[i],"+P") == 0)
+            else if (strcmp(arguments.argv[i], "+P") == 0)
                  pedantic = true;
-            else if (arguments.argv[i][0] == U_PLUS && arguments.argv[i][1] == U_T)
+            else if (arguments.argv[i][1] == 'T')
             {
                 int tab_size = 0;
                 char *image = arguments.argv[i] + 2,
@@ -483,12 +525,12 @@ Option::Option(ArgumentExpander &arguments) :
             }
             else if (strcmp(arguments.argv[i], "+L") == 0)
                  debug_dump_lex = true;
-            else if (strcmp(arguments.argv[i],"+U") == 0)
+            else if (strcmp(arguments.argv[i], "+U") == 0)
             {
                  unzip = true;
                  full_check = true;
             }
-            else if (strcmp(arguments.argv[i],"++") == 0)
+            else if (strcmp(arguments.argv[i], "++") == 0)
             {
                  incremental = true;
                  full_check = true;
@@ -501,132 +543,28 @@ Option::Option(ArgumentExpander &arguments) :
     }
 
     if (! bootclasspath)
-    {
-        bootclasspath = getenv("BOOTCLASSPATH");
-
-        if (bootclasspath)
-        {
-            /* Create a copy of the classpath string we can modify
-               this copy without worry that it will effect the env array */
-            paths_buffer = new char[strlen(bootclasspath)+1];
-            strcpy(paths_buffer, bootclasspath);
-            bootclasspath = paths_buffer;
-
-#ifdef EBCDIC
-            //
-            //  Maintain CLASSPATH in ASCII and translate back to EBCDIC when building file name
-            //
-            for (int k = 0; k < strlen(bootclasspath); k++)
-                bootclasspath[k] = Code::ToASCII(bootclasspath[k]);
-#endif
-            while (isspace(*bootclasspath))
-                bootclasspath++;
-
-            if (*bootclasspath == U_NULL) {
-	        // potential memory leak here, if that incr above executed.
-                delete [] bootclasspath;
-                bootclasspath = NULL;
-            }
-        }
-    }
-
+        // Create a clean copy of the bootclasspath envvar so we can modify
+        //   this copy and delete it later in ~JikesOption
+        bootclasspath = makeStrippedCopy(getenv("BOOTCLASSPATH"));
     if (! extdirs)
-    {
-        extdirs = getenv("EXTDIRS");
-
-        if (extdirs)
-        {
-            /* Create a copy of the extdirs string we can modify
-               this copy without worry that it will effect the env array */
-            paths_buffer = new char[strlen(extdirs)+1];
-            strcpy(paths_buffer, extdirs);
-            extdirs = paths_buffer;
-
-#ifdef EBCDIC
-            //
-            //  Maintain CLASSPATH in ASCII and translate back to EBCDIC when building file name
-            //
-            for (int k = 0; k < strlen(extdirs); k++)
-                extdirs[k] = Code::ToASCII(extdirs[k]);
-#endif
-            while (isspace(*extdirs))
-                extdirs++;
-
-            if (*extdirs == U_NULL) {
-	        // potential memory leak here, if that incr above executed.
-                delete [] extdirs;
-                extdirs = NULL;
-            }
-        }
-    }
-
+        // Create a clean copy of the extdirs envvar so we can modify
+        //   this copy and delete it later in ~JikesOption
+        extdirs = makeStrippedCopy(getenv("EXTDIRS"));
     if (! classpath)
     {
-        classpath = getenv("JIKESPATH");
+        // Create a clean copy of the jikespath envvar so we can modify
+        //   this copy and delete it later in ~JikesOption
+        classpath = makeStrippedCopy(getenv("JIKESPATH"));
         if (! classpath)
-            classpath = getenv("CLASSPATH");
-
-        if (classpath)
-        {
-            /* Create a copy of the classpath string we can modify
-               this copy without worry that it will effect the env array */
-            paths_buffer = new char[strlen(classpath)+1];
-            strcpy(paths_buffer, classpath);
-            classpath = paths_buffer;
-
-#ifdef EBCDIC
-            //
-            //  Maintain CLASSPATH in ASCII and translate back to EBCDIC when building file name
-            //
-            for (int k = 0; k < strlen(classpath); k++)
-                classpath[k] = Code::ToASCII(classpath[k]);
-#endif
-            while (isspace(*classpath))
-                classpath++;
-
-            if (*classpath == U_NULL) {
-	        // potential memory leak here, if that incr above executed.
-                delete [] classpath;
-                classpath = NULL;
-            }
-        }
-
-        if (! classpath)
-        {
-            classpath = new char[2];
-            classpath[0] = '.';
-            classpath[1] = U_NULL;
-        }
+        // Create a clean copy of the classpath envvar so we can modify
+        //   this copy and delete it later in ~JikesOption
+            classpath = makeStrippedCopy(getenv("CLASSPATH"));
     }
-
     if (! sourcepath)
     {
-        sourcepath = getenv("SOURCEPATH");
-
-        if (sourcepath)
-        {
-            /* Create a copy of the sourcepath string we can modify
-               this copy without worry that it will effect the env array */
-            paths_buffer = new char[strlen(sourcepath)+1];
-            strcpy(paths_buffer, sourcepath);
-            sourcepath = paths_buffer;
-
-#ifdef EBCDIC
-            //
-            //  Maintain CLASSPATH in ASCII and translate back to EBCDIC when building file name
-            //
-            for (int k = 0; k < strlen(sourcepath); k++)
-                sourcepath[k] = Code::ToASCII(sourcepath[k]);
-#endif
-            while (isspace(*sourcepath))
-                sourcepath++;
-
-            if (*sourcepath == U_NULL) {
-	        // potential memory leak here, if that incr above executed.
-                delete [] sourcepath;
-                sourcepath = NULL;
-            }
-        }
+        // Create a clean copy of the sourcepath envvar so we can modify
+        //   this copy and delete it later in ~JikesOption
+        sourcepath = makeStrippedCopy(getenv("SOURCEPATH"));
 
         if (! sourcepath)
         {
@@ -635,46 +573,6 @@ Option::Option(ArgumentExpander &arguments) :
             sourcepath[1] = U_NULL;
         }
     }
-    
-    // If we need to do a cygwin CLASSPATH conversion do it after the env is checked
-    // so that it will work for a -classpath argument or a CLASSPATH env var.
-
-#ifdef HAVE_CYGWIN_WIN32_TO_POSIX_PATH_LIST
-    // Under Cygwin, we convert a windows style path into a unix
-    // style path. A path like "C:\Cygwin\tmp;C:\Windows" is converted
-    // into "/tmp:/cygdrive/c/Windows" (assuming C:\Cygwin is cygroot).
-    // We can then parse it using the unix path seperator char ':'
-    if (classpath) {
-      paths_buffer = new char[cygwin_win32_to_posix_path_list_buf_size(classpath)];
-      cygwin_win32_to_posix_path_list(classpath, paths_buffer);
-      delete [] classpath;
-      classpath = paths_buffer;
-    }
-
-    // Do the same for all the other paths.
-    if (bootclasspath) {
-      paths_buffer = new
-        char[cygwin_win32_to_posix_path_list_buf_size(bootclasspath)];
-      cygwin_win32_to_posix_path_list(bootclasspath, paths_buffer);
-      delete[] bootclasspath;
-      bootclasspath = paths_buffer;
-    }
-
-    if (extdirs) {
-      paths_buffer = new char[cygwin_win32_to_posix_path_list_buf_size(extdirs)];
-      cygwin_win32_to_posix_path_list(extdirs, paths_buffer);
-      delete[] extdirs;
-      extdirs = paths_buffer;
-    }
-
-    if (sourcepath) {
-      paths_buffer = new
-        char[cygwin_win32_to_posix_path_list_buf_size(sourcepath)];
-      cygwin_win32_to_posix_path_list(sourcepath, paths_buffer);
-      delete[] sourcepath;
-      sourcepath = paths_buffer;
-    }
-#endif
 
     //
     // Initially, first_file_index is set to argc. Since the array filename_index
@@ -717,7 +615,7 @@ Option::~Option()
     return;
 }
 
-#ifdef	HAVE_JIKES_NAMESPACE
-}			// Close namespace Jikes block
+#ifdef HAVE_JIKES_NAMESPACE
+} // Close namespace Jikes block
 #endif
 
