@@ -1,18 +1,19 @@
-// $Id: scanner.cpp,v 1.17 2001/01/10 16:49:45 mdejong Exp $
+// $Id: scanner.cpp,v 1.20 2001/09/14 05:31:34 ericb Exp $
 //
 // This software is subject to the terms of the IBM Jikes Compiler
 // License Agreement available at the following URL:
-// http://www.ibm.com/research/jikes.
-// Copyright (C) 1996, 1998, International Business Machines Corporation
-// and others.  All Rights Reserved.
+// http://ibm.com/developerworks/opensource/jikes.
+// Copyright (C) 1996, 1998, 1999, 2000, 2001 International Business
+// Machines Corporation and others.  All Rights Reserved.
 // You must accept the terms of that agreement to use this software.
 //
+
 #include "scanner.h"
 #include "control.h"
 #include "error.h"
 
-#ifdef	HAVE_JIKES_NAMESPACE
-namespace Jikes {	// Open namespace Jikes block
+#ifdef HAVE_JIKES_NAMESPACE
+namespace Jikes { // Open namespace Jikes block
 #endif
 
 int (*Scanner::scan_keyword[13]) (wchar_t *p1) =
@@ -43,6 +44,11 @@ Scanner::Scanner(Control &control_) : control(control_)
     //
     assert(NUM_TERMINALS < 128);
 
+    //
+    // If this assertion fails, then gencode.java is at fault.
+    //
+    assert(Code::CodeCheck());
+
     //
     // -------------------------------------------------------------------------------
     // We are pulling this code out because we are tired of defending it. We
@@ -187,7 +193,7 @@ void Scanner::Scan(FileSymbol *file_symbol)
         if (control.option.dump_errors)
         {
             lex -> SortMessages();
-            for(int i = 0; i < lex -> bad_tokens.Length(); i++)
+            for (int i = 0; i < lex -> bad_tokens.Length(); i++)
                 JikesAPI::getInstance()->reportError(&(lex->bad_tokens[i]));
         }
         lex -> DestroyInput(); // get rid of input buffer
@@ -445,7 +451,7 @@ int Scanner::ScanKeyword2(wchar_t *p1)
 
 int Scanner::ScanKeyword3(wchar_t *p1)
 {
-    switch(*p1)
+    switch (*p1)
     {
         case U_f:
             if (p1[1] == U_o && p1[2] == U_r)
@@ -616,7 +622,7 @@ int Scanner::ScanKeyword6(wchar_t *p1)
 
 int Scanner::ScanKeyword7(wchar_t *p1)
 {
-    switch(*p1)
+    switch (*p1)
     {
         case U_b:
             if (p1[1] == U_o && p1[2] == U_o && p1[3] == U_l &&
@@ -652,7 +658,7 @@ int Scanner::ScanKeyword7(wchar_t *p1)
 
 int Scanner::ScanKeyword8(wchar_t *p1)
 {
-    switch(*p1)
+    switch (*p1)
     {
         case U_a:
             if (p1[1] == U_b && p1[2] == U_s &&
@@ -1575,7 +1581,7 @@ void Scanner::ClassifyNonAsciiUnicode()
     return;
 }
 
-#ifdef	HAVE_JIKES_NAMESPACE
-}			// Close namespace Jikes block
+#ifdef HAVE_JIKES_NAMESPACE
+} // Close namespace Jikes block
 #endif
 
